==> vacuum-1.1.0.tar.xz: vacuum-1.1.0/src/translations/uk/socksstreams.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="uk" sourcelanguage="en">
<context>
    <name>SocksOptionsClass</name>
    <message>
        <source>Incoming Direct Connections</source>
        <translation>Вхідне пряме підключення</translation>
    </message>
    <message>
        <source>Disable direct connections</source>
        <translation>Заборонити прямі підключення</translation>
    </message>
    <message>
        <source>Port Forwarding</source>
        <translation>Перенаправлення портів</translation>
    </message>
    <message>
        <source>Host:</source>
        <translation>Хост:</translation>
    </message>
    <message>
        <source>Port:</source>
        <translation>Порт:</translation>
    </message>
    <message>
        <source>Stream Proxy</source>
        <translation>Проксі потоку</translation>
    </message>
    <message>
        <source>Add</source>
        <translation>Додати</translation>
    </message>
    <message>
        <source>Up</source>
        <translation>Вгору</translation>
    </message>
    <message>
        <source>Down</source>
        <translation>Вниз</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Видалити</translation>
    </message>
    <message>
        <source>Connection Proxy</source>
        <translation>Проксі підключення</translation>
    </message>
    <message>
        <source>Use account connection proxy settings</source>
        <translation>Використовувати настройки проксі з аккаунту</translation>
    </message>
    <message>
        <source>Listening port:</source>
        <translation>Порт, що прослуховується:</translation>
    </message>
    <message>
        <source>Use proxy on account server</source>
        <translation>Використовувати проксі на сервері аккаунту</translation>
    </message>
</context>
<context>
    <name>SocksStream</name>
    <message>
        <source>Stream destroyed</source>
        <translation>Потік видалений</translation>
    </message>
    <message>
        <source>Unsupported stream mode</source>
        <translation>Непідтримуваний режим потоку</translation>
    </message>
    <message>
        <source>Remote client cant connect to given hosts</source>
        <translation>Віддалений клієнт не зміг підключитись до отриманих хостів</translation>
    </message>
    <message>
        <source>Failed to activate stream</source>
        <translation>Не вдалось активувати потік</translation>
    </message>
    <message>
        <source>Remote client is timed out to connect</source>
        <translation>Віддалений клієнт не відповів на запит підключення</translation>
    </message>
    <message>
        <source>Failed to create hosts</source>
        <translation>Не вдалось створити хост</translation>
    </message>
    <message>
        <source>Direct connection not established</source>
        <translation>Пряме підключення не встановлено</translation>
    </message>
    <message>
        <source>Invalid host</source>
        <translation>Невірний хост</translation>
    </message>
    <message>
        <source>Cant connect to given hosts</source>
        <translation>Не вдалось підключитись до отриманих хостів</translation>
    </message>
    <message>
        <source>Failed to connect to host</source>
        <translation>Не вдалось підключитись до хосту</translation>
    </message>
</context>
<context>
    <name>SocksStreams</name>
    <message>
        <source>SOCKS5 Data Stream</source>
        <translation>SOCKS5 потік даних</translation>
    </message>
    <message>
        <source>Allows to initiate SOCKS5 stream of data between two XMPP entities</source>
        <translation>Дозволяє ініціювати SOCKS5 потік даних між двома XMPP-сутностями</translation>
    </message>
    <message>
        <source>Supports the initiating of the SOCKS5 stream of data between two XMPP entities</source>
        <translation>Підтримує ініціалізацію SOCKS5 потоку даних між двома XMPP-сутностями</translation>
    </message>
    <message>
        <source>Data is transferred out-band over TCP or UDP connection</source>
        <translation>Дані передаються по окремому TCP або UDP підключенню</translation>
    </message>
</context>
</TS>

==> vacuum-1.1.2_1798.tar.xz: vacuum-1.1.2_1798/src/translations/uk/socksstreams.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="uk" sourcelanguage="en">
<context>
    <name>SocksOptionsClass</name>
    <message>
        <source>Disable direct connections</source>
        <translation>Заборонити прямі підключення</translation>
    </message>
    <message>
        <source>Port Forwarding</source>
        <translation>Перенаправлення портів</translation>
    </message>
    <message>
        <source>Host:</source>
        <translation>Хост:</translation>
    </message>
    <message>
        <source>Port:</source>
        <translation>Порт:</translation>
    </message>
    <message>
        <source>Stream Proxy</source>
        <translation>Проксі потоку</translation>
    </message>
    <message>
        <source>Add</source>
        <translation>Додати</translation>
    </message>
    <message>
        <source>Up</source>
        <translation>Вгору</translation>
    </message>
    <message>
        <source>Down</source>
        <translation>Вниз</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Видалити</translation>
    </message>
    <message>
        <source>Connection Proxy</source>
        <translation>Проксі підключення</translation>
    </message>
    <message>
        <source>Use account connection proxy settings</source>
        <translation>Використовувати настройки проксі з аккаунту</translation>
    </message>
    <message>
        <source>Listening port:</source>
        <translation>Порт, що прослуховується:</translation>
    </message>
    <message>
        <source>Use proxy on account server</source>
        <translation>Використовувати проксі на сервері аккаунту</translation>
    </message>
    <message>
        <source>Outgoing Connections</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Connect timeout:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>seconds</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Incoming Connections</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>SocksStream</name>
    <message>
        <source>Stream destroyed</source>
        <translation>Потік видалений</translation>
    </message>
    <message>
        <source>Unsupported stream mode</source>
        <translation>Непідтримуваний режим потоку</translation>
    </message>
    <message>
        <source>Remote client cant connect to given hosts</source>
        <translation>Віддалений клієнт не зміг підключитись до отриманих хостів</translation>
    </message>
    <message>
        <source>Failed to activate stream</source>
        <translation>Не вдалось активувати потік</translation>
    </message>
    <message>
        <source>Failed to create hosts</source>
        <translation>Не вдалось створити хост</translation>
    </message>
    <message>
        <source>Direct connection not established</source>
        <translation>Пряме підключення не встановлено</translation>
    </message>
    <message>
        <source>Invalid host</source>
        <translation>Невірний хост</translation>
    </message>
    <message>
        <source>Cant connect to given hosts</source>
        <translation>Не вдалось підключитись до отриманих хостів</translation>
    </message>
    <message>
        <source>Failed to connect to host</source>
        <translation>Не вдалось підключитись до хосту</translation>
    </message>
</context>
<context>
    <name>SocksStreams</name>
    <message>
        <source>SOCKS5 Data Stream</source>
        <translation>SOCKS5 потік даних</translation>
    </message>
    <message>
        <source>Allows to initiate SOCKS5 stream of data between two XMPP entities</source>
        <translation>Дозволяє ініціювати SOCKS5 потік даних між двома XMPP-сутностями</translation>
    </message>
    <message>
        <source>Supports the initiating of the SOCKS5 stream of data between two XMPP entities</source>
        <translation>Підтримує ініціалізацію SOCKS5 потоку даних між двома XMPP-сутностями</translation>
    </message>
    <message>
        <source>Data is transferred out-band over TCP or UDP connection</source>
        <translation>Дані передаються по окремому TCP або UDP підключенню</translation>
    </message>
</context>
</TS>
